==> texinfo-6.8.90.tar.xz: texinfo-6.8.90/tp/t/results/init_files_tests/modified_translation.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'modified_translation'} = {
  'contents' => [
    {
      'contents' => [
        {
          'contents' => [
            {
              'args' => [
                {
                  'parent' => {},
                  'type' => 'brace_command_arg'
                }
              ],
              'cmdname' => 'error',
              'parent' => {},
              'source_info' => {
                'file_name' => '',
                'line_nr' => 1,
                'macro' => ''
              }
            },
            {
              'parent' => {},
              'text' => '.
'
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'args' => [
            {
              'contents' => [
                {
                  'parent' => {},
                  'text' => 'fr'
                }
              ],
              'extra' => {
                'spaces_after_argument' => '
'
              },
              'parent' => {},
              'type' => 'line_arg'
            }
          ],
          'cmdname' => 'documentlanguage',
          'extra' => {
            'spaces_before_argument' => ' ',
            'text_arg' => 'fr'
          },
          'parent' => {},
          'source_info' => {
            'file_name' => '',
            'line_nr' => 3,
            'macro' => ''
          }
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'fr '
            },
            {
              'args' => [
                {
                  'parent' => {},
                  'type' => 'brace_command_arg'
                }
              ],
              'cmdname' => 'error',
              'parent' => {},
              'source_info' => {
                'file_name' => '',
                'line_nr' => 5,
                'macro' => ''
              }
            },
            {
              'parent' => {},
              'text' => '.
'
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'args' => [
            {
              'contents' => [
                {
                  'parent' => {},
                  'text' => 'pt'
                }
              ],
              'extra' => {
                'spaces_after_argument' => '
'
              },
              'parent' => {},
              'type' => 'line_arg'
            }
          ],
          'cmdname' => 'documentlanguage',
          'extra' => {
            'spaces_before_argument' => ' ',
            'text_arg' => 'pt'
          },
          'parent' => {},
          'source_info' => {
            'file_name' => '',
            'line_nr' => 7,
            'macro' => ''
          }
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'pt '
            },
            {
              'args' => [
                {
                  'parent' => {},
                  'type' => 'brace_command_arg'
                }
              ],
              'cmdname' => 'error',
              'parent' => {},
              'source_info' => {
                'file_name' => '',
                'line_nr' => 9,
                'macro' => ''
              }
            },
            {
              'parent' => {},
              'text' => '.
'
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'parent' => {},
      'type' => 'before_node_section'
    }
  ],
  'type' => 'document_root'
};
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0]{'contents'}[0];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0]{'contents'}[0];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0]{'contents'}[2]{'args'}[0];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0]{'contents'}[2];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[4]{'contents'}[0]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0]{'contents'}[4];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[4]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0]{'contents'}[4]{'contents'}[1];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[4]{'contents'}[1]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0]{'contents'}[4];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[4]{'contents'}[2]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0]{'contents'}[4];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[4]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[5]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0]{'contents'}[6]{'args'}[0];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0]{'contents'}[6];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[6]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[7]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[8]{'contents'}[0]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0]{'contents'}[8];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[8]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0]{'contents'}[8]{'contents'}[1];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[8]{'contents'}[1]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0]{'contents'}[8];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[8]{'contents'}[2]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0]{'contents'}[8];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[8]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0];
$result_trees{'modified_translation'}{'contents'}[0]{'contents'}[9]{'parent'} = $result_trees{'modified_translation'}{'contents'}[0];
$result_trees{'modified_translation'}{'contents'}[0]{'parent'} = $result_trees{'modified_translation'};

$result_texis{'modified_translation'} = '@error{}.

@documentlanguage fr

fr @error{}.

@documentlanguage pt

pt @error{}.

';


$result_texts{'modified_translation'} = 'error-->.


fr error-->.


pt error-->.

';

$result_errors{'modified_translation'} = [];


$result_floats{'modified_translation'} = {};



$result_converted{'html'}->{'modified_translation'} = '<!DOCTYPE html>
<html>
<!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
<title>Untitled Document</title>

<meta name="description" content="Untitled Document">
<meta name="keywords" content="Untitled Document">
<meta name="resource-type" content="document">
<meta name="distribution" content="global">
<meta name="viewport" content="width=device-width,initial-scale=1">



</head>

<body lang="en">
<p>Special Form.
</p>

<p>fr Forme Sp@\'eciale.
</p>

<p>pt Formulário especial.
</p>



</body>
</html>
';

$result_converted_errors{'html'}->{'modified_translation'} = [
  {
    'error_line' => 'warning: must specify a title with a title command or @top
',
    'text' => 'must specify a title with a title command or @top',
    'type' => 'warning'
  }
];


1;

==> texinfo_7.1.1.orig.tar.xz: texinfo-7.1.1/tp/t/results/init_files_tests/modified_translation.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'modified_translation'} = {
  'contents' => [
    {
      'contents' => [
        {
          'contents' => [
            {
              'args' => [
                {
                  'type' => 'brace_command_arg'
                }
              ],
              'cmdname' => 'error',
              'source_info' => {
                'file_name' => '',
                'line_nr' => 1,
                'macro' => ''
              }
            },
            {
              'text' => '.
'
            }
          ],
          'type' => 'paragraph'
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'args' => [
            {
              'contents' => [
                {
                  'text' => 'fr'
                }
              ],
              'info' => {
                'spaces_after_argument' => {
                  'text' => '
'
                }
              },
              'type' => 'line_arg'
            }
          ],
          'cmdname' => 'documentlanguage',
          'extra' => {
            'text_arg' => 'fr'
          },
          'info' => {
            'spaces_before_argument' => {
              'text' => ' '
            }
          },
          'source_info' => {
            'file_name' => '',
            'line_nr' => 3,
            'macro' => ''
          }
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'text' => 'fr '
            },
            {
              'args' => [
                {
                  'type' => 'brace_command_arg'
                }
              ],
              'cmdname' => 'error',
              'source_info' => {
                'file_name' => '',
                'line_nr' => 5,
                'macro' => ''
              }
            },
            {
              'text' => '.
'
            }
          ],
          'type' => 'paragraph'
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'args' => [
            {
              'contents' => [
                {
                  'text' => 'pt'
                }
              ],
              'info' => {
                'spaces_after_argument' => {
                  'text' => '
'
                }
              },
              'type' => 'line_arg'
            }
          ],
          'cmdname' => 'documentlanguage',
          'extra' => {
            'text_arg' => 'pt'
          },
          'info' => {
            'spaces_before_argument' => {
              'text' => ' '
            }
          },
          'source_info' => {
            'file_name' => '',
            'line_nr' => 7,
            'macro' => ''
          }
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'text' => 'pt '
            },
            {
              'args' => [
                {
                  'type' => 'brace_command_arg'
                }
              ],
              'cmdname' => 'error',
              'source_info' => {
                'file_name' => '',
                'line_nr' => 9,
                'macro' => ''
              }
            },
            {
              'text' => '.
'
            }
          ],
          'type' => 'paragraph'
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'type' => 'before_node_section'
    }
  ],
  'type' => 'document_root'
};

$result_texis{'modified_translation'} = '@error{}.

@documentlanguage fr

fr @error{}.

@documentlanguage pt

pt @error{}.

';


$result_texts{'modified_translation'} = 'error-->.


fr error-->.


pt error-->.

';

$result_errors{'modified_translation'} = [];


$result_floats{'modified_translation'} = {};



$result_converted{'html'}->{'modified_translation'} = '<!DOCTYPE html>
<html>
<!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
<title>Untitled Document</title>

<meta name="description" content="Untitled Document">
<meta name="keywords" content="Untitled Document">
<meta name="resource-type" content="document">
<meta name="distribution" content="global">
<meta name="viewport" content="width=device-width,initial-scale=1">



</head>

<body lang="en">
<p>Special Form.
</p>

<p>fr Forme Sp@\'eciale.
</p>

<p>pt Formulário especial.
</p>



</body>
</html>
';

$result_converted_errors{'html'}->{'modified_translation'} = [
  {
    'error_line' => 'warning: must specify a title with a title command or @top
',
    'text' => 'must specify a title with a title command or @top',
    'type' => 'warning'
  }
];


1;
